@@ -14,11 +14,11 @@ String::Copyright - Representation of text-based copyright statements
 
 =head1 VERSION
 
-Version 0.003004
+Version 0.003005
 
 =cut
 
-our $VERSION = '0.003004';
+our $VERSION = '0.003005';
 
 # Dependencies
 use parent 'Exporter::Tiny';
@@ -98,6 +98,7 @@ my $blank_re          = qr/[ \t]/;
 my $blank_or_break_re = qr/$blank_re*\n?$blank_re*/;
 my $sign_re = qr/copyright(?:-holders?)?|copr\.|[©⒞Ⓒⓒ🄒🄫🅒]/i;
 my $pseudo_sign_re = qr/\(c\)/i;
+my $broken_sign_re = qr/\?$blank_re*/;
 
 my $year_re = qr/\b[0-9]{4}\b/;
 my $comma_re
@@ -117,8 +118,16 @@ my $boilerplate_re
 # (?i)copyright (?:(?:claim|holder|info|information|notice|owner|ownership|statement|string)s?|in|is|to)@\w
 # (?i)copyright (?:(?:claim|holder|info|information|notice|owner|ownership|statement|string)s?|in|is|to)@\b[-_@]
 # (?im)copyright (?:(?:claim|holder|info|information|notice|owner|ownership|statement|string)s?|in|is|to)[^ $]
+my $chatter_copyright_re
+	= qr/(?:assigned|claim|holder|info|information|law|notice|owner|ownership|statement|string)s?|and|eq|generated|in|is|on|to/i;
+my $the_notname_re
+	= qr/concrete|fault|first|immediately|least|min\/max|one|outer|previous|ratio|sum|user/i;
+my $the_sentence_re
+	= qr/(?:\w+$blank_re+){1,10}(?:are|can(?:not)?|in|is|must|was)/i;
+my $chatter_pseudosign_re
+	= qr/(?:the$blank_re+(?:$the_notname_re|$the_sentence_re)|there)\b/;
 my $chatter_re
-	= qr/copyright$blank_or_break_re(?:(?:assigned|claim|eq|generated|holder|info|information|law|notice|owner|ownership|statement|string)s?|and|in|is|on|to)(?:$|@\W|[^a-zA-Z0-9@_-])/im;
+	= qr/copyright$blank_or_break_re$chatter_copyright_re(?:$|@\W|[^a-zA-Z0-9@_-])|$blank_re*$pseudo_sign_re$blank_or_break_re+$chatter_pseudosign_re/im;
 
 my $signs_re
 	= qr/(?:$sign_re|(?:^|$blank_re)$pseudo_sign_re)(?:$blank_re+(?:$sign_re|$pseudo_sign_re))*/m;
@@ -127,7 +136,7 @@ my $years_re    = qr/$yearspan_re(?:$comma_re$yearspan_re)*/;
 my $owners_re   = qr/$owner_prefix_re*$owner_initial_re\S*(?:$blank_re*\S+)*/;
 
 my $signs_and_more_re
-	= qr/(?:$chatter_re.*|$signs_re(?::$blank_or_break_re|$comma_re)($years_re?$comma_re?$owner_intro_re?$owners_re?)|(?:\n|\z))/;
+	= qr/(?:$chatter_re.*|$signs_re(?::$blank_or_break_re|$comma_re)$broken_sign_re?($years_re?$comma_re?$owner_intro_re?$owners_re?)|(?:\n|\z))/;
 
 sub _generate_copyright
 {
@@ -192,7 +201,7 @@ sub _generate_copyright
 				$owners =~ s/^$owner_intro_re//g;
 				$owners =~ s/\s{2,}/ /g;
 				$owners =~ s/^$owner_intro_re//g;
-				$owners =~ s/$boilerplate_re//g;
+				$owners =~ s/$boilerplate_re.*//g;
 			}
 
 # split owner into owner_id and owner
